@@ -31,6 +31,11 @@ class DescribeBackupsRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_BackupJobId(self): # Integer
+		return self.get_query_params().get('BackupJobId')
+
+	def set_BackupJobId(self, BackupJobId):  # Integer
+		self.add_query_param('BackupJobId', BackupJobId)
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
